@@ -90,7 +90,7 @@ starter_filter = click.option(
     "--starter",
     default=None,
     multiple=True,
-    help="filter starters (supports pattern matching *,?,[]) " \
+    help="filter starters (supports pattern matching *,?,[]) "
     "(multiple values are ORed together)",
 )
 
@@ -289,7 +289,7 @@ def _server_str(server, color=False):
 def _server_host_str(server, color=False):
     host = server if isinstance(server, str) else server.host
     host = "---" if host == "nada" else host
-    return click.style(host, fg="black" if color else None)
+    return click.style(host, fg="white" if color else None, dim=True if color else None)
 
 
 def _device_class_str(dev, color=False):
@@ -694,6 +694,33 @@ def device_delete(devices):
         tangoctl.device_delete(devices)
 
 
+@device_group.group("alias")
+def device_alias():
+    """device alias operations(add/remove/show)"""
+
+
+@device_alias.command("show")
+@device
+def device_alias_show(device):
+    """show the alias for the given device"""
+    click.echo(tangoctl.alias_from_device(device))
+
+
+@device_alias.command("add")
+@device
+@click.argument("alias", type=str)
+def device_alias_add(device, alias):
+    """set the alias for the given device"""
+    tangoctl.set_device_alias(device, alias)
+
+
+@device_alias.command("remove")
+@click.argument("alias", type=str)
+def device_alias_remove(device, alias):
+    """unregister the alias from the database"""
+    tangoctl.remove_device_alias(alias)
+
+
 @device_group.group("command")
 def device_command():
     """
@@ -1115,43 +1142,14 @@ def server_tree(
             ├── sys/tg_test/tc2
             └── sys/tg_test/tc3
     """
-    db = None
-    db_info = tangoctl.get_db_info(db=db)
-    db_name = db_info.name
-
-    import treelib
-
-    tree = treelib.Tree()
-    db_node = tree.create_node(db_name)
-    servers = tangoctl.iter_servers(
-        server=server, server_type=server_type, server_instance=server_instance, db=db
+    tree = tangoctl.server_tree(
+        server_name=server,
+        server_type=server_type,
+        server_instance=server_instance,
+        compact=compact,
+        server_only=server_only,
+        exclude_dserver=exclude_dserver,
     )
-
-    if compact:
-        for serv in servers:
-            serv_inst_node = tree.create_node(serv.name, parent=db_node)
-            if not server_only:
-                for device in sorted(serv.devices):
-                    if exclude_dserver and device.lower().startswith("dserver/"):
-                        continue
-                    tree.create_node(device, parent=serv_inst_node)
-    else:
-        # group servers by type
-        serv_map = collections.defaultdict(dict)
-        for serv in servers:
-            serv_map[serv.type][serv.instance] = serv
-
-        for serv_type in sorted(serv_map):
-            instances = serv_map[serv_type]
-            serv_type_node = tree.create_node(serv_type, parent=db_node)
-            for serv_inst in sorted(instances):
-                serv = instances[serv_inst]
-                serv_inst_node = tree.create_node(serv_inst, parent=serv_type_node)
-                if not server_only:
-                    for device in sorted(serv.devices):
-                        if exclude_dserver and device.lower().startswith("dserver/"):
-                            continue
-                        tree.create_node(device, parent=serv_inst_node)
     click.echo(str(tree))
 
 
@@ -1262,50 +1260,14 @@ def starter_tree(starter, server, server_type, server_instance, all):
             ├── Sardana/BL04
             └── Lima/basler-01
     """
-    db = None
-    db_info = tangoctl.get_db_info(db=db)
-    db_name = db_info.name
-
-    import treelib
-
-    tree = treelib.Tree()
-    db_node = tree.create_node(db_name)
-    starters = list(tangoctl.iter_starters(starter_name=starter, db=db))
-    starters_servers = tangoctl.starters_servers(*starters)
-    for starter in starters:
-        level_servers = collections.defaultdict(list)
-        servers = starters_servers[starter]
-        fg = "red" if servers is None else "green"
-        name = click.style(starter.name, fg=fg)
-        starter_node = tree.create_node(name, parent=db_node)
-        servers = servers.values() if servers else []
-        servers = tangoctl.iter_starter_servers(
-            servers, server, server_type, server_instance
-        )
-        for starter_server in servers:
-            level = level_servers[starter_server["level"]]
-            level.append(starter_server)
-        for level in sorted(level_servers):
-            if level == 0:
-                if not all:
-                    continue
-                name = "Not controlled"
-            else:
-                name = "level {}".format(level)
-            level_node = tree.create_node(name, parent=starter_node)
-            for starter_server in level_servers[level]:
-                state = starter_server["state"]
-                if state == "ON":
-                    color = "green"
-                elif state == "FAULT":
-                    color = "red"
-                elif state == "MOVING":
-                    color = "blue"
-                else:
-                    color = "magenta"
-                label = click.style(starter_server["name"], fg=color)
-                tree.create_node(label, parent=level_node)
-
+    tree = tangoctl.starter_tree(
+        starter_name=starter,
+        server_name=server,
+        server_type=server_type,
+        server_instance=server_instance,
+        all=all,
+        colored=True,
+    )
     click.echo(str(tree))
 
 
@@ -1407,7 +1369,9 @@ def starter_start(starter, server, server_type, server_instance, timeout, dry_ru
     (level+1) servers are started only when all lower level servers
     have been started.
     """
-    return _starter_start(starter, server, server_type, server_instance, timeout, dry_run)
+    return _starter_start(
+        starter, server, server_type, server_instance, timeout, dry_run
+    )
 
 
 @starter_group.command("restart")
@@ -1445,7 +1409,9 @@ def starter_restart(starter, server, server_type, server_instance, timeout, dry_
         (level+1) servers are started only when all lower level servers
         have been started.
     """
-    return _starter_restart(starter, server, server_type, server_instance, timeout, dry_run)
+    return _starter_restart(
+        starter, server, server_type, server_instance, timeout, dry_run
+    )
 
 
 if __name__ == "__main__":
