@@ -16,8 +16,7 @@ import collections
 import gevent
 import tango.gevent
 
-import colorful
-
+import click
 
 Database = tango.Database
 Device = tango.gevent.DeviceProxy
@@ -324,17 +323,6 @@ def fnmatch_any(name, patterns, case_insensitive=False):
     return any(fnmatch.fnmatch(name, pattern) for pattern in patterns)
 
 
-def style(msg, fg=None, bg=None, bold=None, underlined=None, inversed=None):
-    st = []
-    bold and st.append("bold")
-    underlined and st.append("underlined")
-    inversed and st.append("inversed")
-    fg and st.append(fg)
-    bg and st.append("on_" + bg)
-    f = getattr(colorful, "_".join(st))
-    return f(msg)
-
-
 # ----- API -----
 
 
@@ -1112,8 +1100,8 @@ def starter_tree(
     for starter in starters:
         level_servers = collections.defaultdict(list)
         servers = starters_servers_dict[starter]
-        fg = "red2" if servers is None else "green3"
-        name = str(style(starter.name, fg=fg)) if colored else starter.name
+        fg = "red" if servers is None else "green"
+        name = click.style(starter.name, fg=fg) if colored else starter.name
         starter_node = tree.create_node(name, parent=db_node)
         servers = servers.values() if servers else []
         servers = iter_starter_servers(
@@ -1135,13 +1123,13 @@ def starter_tree(
                 label = starter_server["name"]
                 if colored:
                     if state == "ON":
-                        color = "green3"
+                        color = "green"
                     elif state == "FAULT":
-                        color = "red2"
+                        color = "red"
                     elif state == "MOVING":
-                        color = "royalBlue1"
+                        color = "blue"
                     else:
                         color = "magenta"
-                    label = str(style(label, fg=color))
+                    label = click.style(label, fg=color)
                 tree.create_node(label, parent=level_node)
     return tree
